@@ -24,10 +24,10 @@ pub enum Value {
 impl Hash for Value {
     fn hash<H: Hasher>(&self, state: &mut H) {
         match self {
-            Self::Null => ().hash(state),
+            Self::Null => 0_u8.hash(state),
             Self::Boolean(v) => v.hash(state),
             Self::Integer(v) => v.hash(state),
-            Self::Decimal(v) => unsafe { transmute::<f64, [u8; 8]>(*v).hash(state) },
+            Self::Decimal(v) => v.to_ne_bytes().hash(state),
             Self::String(v) => v.hash(state),
             Self::Set(v) => {
                 v.len().hash(state);
